@@ -36,6 +36,14 @@ test_that("list_filters", {
   expect_error(svc$list_filters(), NA)
 })
 
+test_that("list_metric_attribution_metrics", {
+  expect_error(svc$list_metric_attribution_metrics(), NA)
+})
+
+test_that("list_metric_attributions", {
+  expect_error(svc$list_metric_attributions(), NA)
+})
+
 test_that("list_recipes", {
   expect_error(svc$list_recipes(), NA)
 })
